***************************************************************************************
* Welfare Assistance to the Poor Mechanical Turk Pilot 
* Open-Ended Question Coding
*
* This .do file creates the analysis reported in TABLE A2 in:
* "Assessing the Programmatic Equivalence Assumption In Question Wording Experiments: 
*   Understanding Why Americans like Assistance to the Poor more than Welfare"
* Public Opinion Quarterly
* Gregory Huber and Celia Paris
*
* This version: July 16, 2012
*
***************************************************************************************

clear
clear matrix
capture log close
set more off 

*****************************
* Loading Data for Table A2 *
*****************************
run WATP02_SUB_Clean_Datasets.do
clear

log using "output\WATP_Log03_TableA2.txt", text replace

use "sourcedata\Clean_WATP_MT.dta"

* Subsetting to Relevant Cases
keep status asstpoorvswelf op_dummy_prog programs 
keep if status=="Complete"
drop if op_dummy_prog==0

* Cleaning Punctuation from Text
foreach lookfortxt in ";" ":" "." "," "\" "/" "$" "!" "?" "(" ")" "&" "-" "_" {
 di "`lookfortxt'"
 replace programs=subinstr(programs,"`lookfortxt'"," ",.) 	/* replaces punctuation marks with space*/
}

* Removing Unnecessary Spaces 
foreach var in programs {
 replace `var'=itrim(`var')
 replace `var'=lower(`var')
 replace `var'=subinstr(`var', "'","",.)
}

* Reloading Cleaned Data
outsheet using "sourcedata\Clean_WATP_MT_OpenTxt.csv", comma replace noquote
clear
insheet using "sourcedata\Clean_WATP_MT_OpenTxt.csv", comma names

* Response Rate
encode programs, gen(progenc)
gen proganswer=(progenc!=.)
tab op_dummy_prog proganswer, row

* Pad responses with space at both end for some lookups
replace programs= " " + programs + " "

* Creating Progam Categories
forvalues i = 1(1)10 {
          generate iscat_`i' = 0
		  }

* Category 1: TANF/AFDC/cash
replace iscat_1=1 if strpos(programs,"afdc")~=0
replace iscat_1=1 if strpos(programs,"cash")~=0
replace iscat_1=1 if strpos(programs,"tanf")~=0
replace iscat_1=1 if strpos(programs,"temporary aid")~=0
replace iscat_1=1 if strpos(programs,"dependent children")~=0
* tab iscat_1 welf_poor if iscat_1==1

* Category 2: Housing
replace iscat_2=1 if strpos(programs,"housing")~=0
replace iscat_2=1 if strpos(programs,"section 8")~=0
replace iscat_2=1 if strpos(programs,"section8")~=0
replace iscat_2=1 if strpos(programs,"rent")~=0

* Category 3: Food Stamps
replace iscat_3=1 if strpos(programs,"food stamps")~=0
replace iscat_3=1 if strpos(programs,"foodstamps")~=0
replace iscat_3=1 if strpos(programs,"snap")~=0
replace iscat_3=1 if strpos(programs,"wic")~=0
replace iscat_3=1 if strpos(programs,"lunch")~=0

* Category 4: Homeless Shelters/Soup Kitchens
replace iscat_4=1 if strpos(programs,"homeless")~=0
replace iscat_4=1 if strpos(programs,"shelter")~=0
replace iscat_4=1 if strpos(programs,"food banks")~=0
replace iscat_4=1 if strpos(programs,"foodbanks")~=0
replace iscat_4=1 if strpos(programs,"soup")~=0
replace iscat_4=1 if strpos(programs,"kitchen")~=0

* Category 5: Daycare/Child Care/Head Start
replace iscat_5=1 if strpos(programs,"daycare")~=0
replace iscat_5=1 if strpos(programs,"day care")~=0
replace iscat_5=1 if strpos(programs,"childcare")~=0
replace iscat_5=1 if strpos(programs,"child care")~=0
replace iscat_5=1 if strpos(programs,"head start")~=0

* Category 6: Social Security/Medicare
replace iscat_6=1 if strpos(programs,"social security")~=0
replace iscat_6=1 if strpos(programs,"medicare")~=0
replace iscat_6=1 if strpos(programs,"seniors")~=0
replace iscat_6=1 if strpos(programs," ssi")~=0
replace iscat_6=1 if strpos(programs,"ssi ")~=0
replace iscat_6=1 if strpos(programs,"old age")~=0

* Category 7: Medicaid/SCHIP
replace iscat_7=1 if strpos(programs,"medicaid")~=0
replace iscat_7=1 if strpos(programs,"chip")~=0

* Category 8: EITC/Child Tax Credit
replace iscat_8=1 if strpos(programs,"eitc")~=0
replace iscat_8=1 if strpos(programs,"earned income")~=0

* Category 9: Unemployment/Disability
replace iscat_9=1 if strpos(programs,"disablty")~=0
replace iscat_9=1 if strpos(programs,"disability")~=0
replace iscat_9=1 if strpos(programs,"ssdi")~=0
replace iscat_9=1 if strpos(programs,"disabilities")~=0
replace iscat_9=1 if strpos(programs,"unemployment ins")~=0
replace iscat_9=1 if strpos(programs,"unemployment benefits")~=0
replace iscat_9=1 if strpos(programs,"training")~=0
replace iscat_9=1 if strpos(programs,"workers comp")~=0

* Category 10: Mentions of "Welfare"
replace iscat_10=1 if strpos(programs,"welfare")~=0
replace iscat_10=1 if strpos(programs,"welf")~=0

tab iscat_1 asstpoorvswelf, col nofreq
tab iscat_2 asstpoorvswelf, col nofreq
tab iscat_3 asstpoorvswelf, col nofreq
tab iscat_4 asstpoorvswelf, col nofreq
tab iscat_5 asstpoorvswelf, col nofreq
tab iscat_6 asstpoorvswelf, col nofreq
tab iscat_7 asstpoorvswelf, col nofreq
tab iscat_8 asstpoorvswelf, col nofreq
tab iscat_9 asstpoorvswelf, col nofreq
tab iscat_10 asstpoorvswelf, col nofreq

sum iscat_10 if asstpoorvswelf=="Welf"
sum iscat_10 if asstpoorvswelf=="AsstPoor"
/* "It is also worth noting that 46% of respondents in the assistance to the poor condition 
used the word welfare in their response, compared to only 4% in the welfare condition." */

* Exporting Means and SE
preserve 
collapse (mean) iscat_1 iscat_2 iscat_3 iscat_4 iscat_5 iscat_6 iscat_7 iscat_8 iscat_9 (semean)  se1=iscat_1 se2=iscat_2 se3=iscat_3 se4=iscat_4 se5=iscat_5 se6=iscat_6 se7=iscat_7 se8=iscat_8 se9=iscat_9, by(asstpoorvswelf) 
outsheet using output\TableA2_PercentMentioningPrograminOpenEndedResponse.csv, replace comma
restore

forvalues i = 1(1)9 {
          ttest iscat_`i', by(asstpoorvswelf) unequal
		  }


log close
